@@ -629,12 +629,14 @@ class Xcmd:
         self.command = []
         for arg in args.command:
             try:
-                result = arg.format(*inputs, **kwargs).split("::list::")
+                val = self.preserve_mustache(arg)
+                result = val.format(*inputs, **kwargs).split("::list::")
+                newval = self.restore_mustache(result)
             except (IndexError, KeyError):
                 LOGGER.error("Invalid replacement string in command: '%s'", arg)
                 sys.exit(1)
-            if result:
-                self.command.extend(result)
+            if newval:
+                self.command.extend(newval)
 
         #  Format all supported mutable options defined in `mutable_args`
         #  Note: only list and string options are supported.
@@ -869,25 +871,31 @@ class MiniCmd:
         parser.add_argument(
             "--input",
             type=str,
-            help="Redirect job stdin from FILENAME, bypassing KVS"
-            if not exclude_io
-            else argparse.SUPPRESS,
+            help=(
+                "Redirect job stdin from FILENAME, bypassing KVS"
+                if not exclude_io
+                else argparse.SUPPRESS
+            ),
             metavar="FILENAME",
         )
         parser.add_argument(
             "--output",
             type=str,
-            help="Redirect job stdout to FILENAME, bypassing KVS"
-            if not exclude_io
-            else argparse.SUPPRESS,
+            help=(
+                "Redirect job stdout to FILENAME, bypassing KVS"
+                if not exclude_io
+                else argparse.SUPPRESS
+            ),
             metavar="FILENAME",
         )
         parser.add_argument(
             "--error",
             type=str,
-            help="Redirect job stderr to FILENAME, bypassing KVS"
-            if not exclude_io
-            else argparse.SUPPRESS,
+            help=(
+                "Redirect job stderr to FILENAME, bypassing KVS"
+                if not exclude_io
+                else argparse.SUPPRESS
+            ),
             metavar="FILENAME",
         )
         parser.add_argument(
@@ -900,9 +908,11 @@ class MiniCmd:
             "-l",
             "--label-io",
             action="store_true",
-            help="Add rank labels to stdout, stderr lines"
-            if not exclude_io
-            else argparse.SUPPRESS,
+            help=(
+                "Add rank labels to stdout, stderr lines"
+                if not exclude_io
+                else argparse.SUPPRESS
+            ),
         )
         parser.add_argument(
             "--cwd", help="Set job working directory", metavar="DIRECTORY"
