@@ -227,9 +227,9 @@ class InstanceInfo:
             if not uri or SchedResourceList is None:
                 raise ValueError
             handle = flux.Flux(str(uri))
-            future = handle.rpc("sched.resource-status")
+            future = flux.resource.resource_list(handle)
             self.stats = StatsInfo(handle).update_sync()
-            self.resources = SchedResourceList(future.get())
+            self.resources = future.get()
             self.initialized = True
             return
         except (ValueError, OSError, FileNotFoundError):
@@ -831,7 +831,7 @@ class JobInfoFormat(flux.util.OutputFormat):
         creations of scheduler or user.
         """
         format_list = string.Formatter().parse(fmt)
-        for (_, field, _, _) in format_list:
+        for _, field, _, _ in format_list:
             if field and not field in self.headings:
                 if field.startswith("annotations."):
                     field_heading = field[len("annotations.") :].upper()
