@@ -175,7 +175,8 @@ class Bottombar:
     def start(self):
         """Start drawing a Bottombar"""
         self._running = True
-        self._t0 = time.time()
+        if self._t0 is None:
+            self._t0 = time.time()
         self.redraw()
         atexit.register(self._reset_terminal)
         return self
@@ -271,7 +272,7 @@ class ProgressBar(Bottombar):
 
     def _formatter(self, bbar, width):
         style = self.style
-        fraction = float(self.count / self.total)
+        fraction = float(self.count / self.total) if self.total else 0
         percent = 100 * fraction
 
         #  Format before/after strings:
