@@ -1638,6 +1638,18 @@ enum job_event_watch_flags {
     FLUX_JOB_EVENT_WATCH_WAITCREATE = 1,
 };
 
+enum job_lookup_flags {
+
+
+
+    FLUX_JOB_LOOKUP_JSON_DECODE = 1,
+
+
+
+
+    FLUX_JOB_LOOKUP_CURRENT = 2,
+};
+
 enum job_urgency {
     FLUX_JOB_URGENCY_MIN = 0,
     FLUX_JOB_URGENCY_HOLD = FLUX_JOB_URGENCY_MIN,
@@ -1692,10 +1704,10 @@ typedef uint64_t flux_jobid_t;
 
 
 int flux_job_id_parse (const char *s, flux_jobid_t *id);
-# 2955 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2967 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_id_encode (flux_jobid_t id, const char *type,
                         char *buf, size_t bufsz);
-# 2966 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 2978 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_job_statetostr (flux_job_state_t state, const char *fmt);
 
 
@@ -1809,16 +1821,16 @@ flux_future_t *flux_job_result (flux_t *h, flux_jobid_t id, int flags);
 
 int flux_job_result_get (flux_future_t *f,
                          const char **json_str);
-# 3097 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3109 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_result_get_unpack (flux_future_t *f, const char *fmt, ...);
-# 3111 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3123 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_job_timeleft (flux_t *h, flux_error_t *errp, double *timeleft);
-# 3127 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3139 "/__w/flux-python/flux-python/src/_core_clean.h"
 char *flux_unwrap_string (const char *in,
                           bool verify,
                           uint32_t *userid,
                           flux_error_t *error);
-# 3155 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3167 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_jobspec1 flux_jobspec1_t;
 typedef flux_error_t flux_jobspec1_error_t;
 
@@ -1916,7 +1928,7 @@ char *flux_jobspec1_encode (flux_jobspec1_t *jobspec, size_t flags);
 
 flux_jobspec1_t *flux_jobspec1_decode (const char *s,
                                        flux_jobspec1_error_t *error);
-# 3266 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3278 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_jobspec1_t *flux_jobspec1_from_command (int argc,
                                              char **argv,
                                              char **env,
@@ -1928,7 +1940,7 @@ flux_jobspec1_t *flux_jobspec1_from_command (int argc,
 
 
 void flux_jobspec1_destroy (flux_jobspec1_t *jobspec);
-# 3322 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3334 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_command flux_cmd_t;
 
 
@@ -1950,7 +1962,7 @@ void flux_cmd_destroy (flux_cmd_t *cmd);
 
 
 int flux_cmd_argv_appendf (flux_cmd_t *cmd,
-             const char *fmt, ...)
+                           const char *fmt, ...)
                            ;
 
 
@@ -1988,10 +2000,10 @@ char *flux_cmd_stringify (const flux_cmd_t *cmd);
 
 
 int flux_cmd_setenvf (flux_cmd_t *cmd,
-        int overwrite,
+                      int overwrite,
                       const char *name,
-        const char *fmt,
-        ...)
+                      const char *fmt,
+                      ...)
                       ;
 
 
@@ -2012,14 +2024,14 @@ const char *flux_cmd_getenv (const flux_cmd_t *cmd, const char *name);
 
 int flux_cmd_setcwd (flux_cmd_t *cmd, const char *cwd);
 const char *flux_cmd_getcwd (const flux_cmd_t *cmd);
-# 3418 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3430 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_cmd_add_channel (flux_cmd_t *cmd, const char *name);
-# 3471 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3467 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_cmd_setopt (flux_cmd_t *cmd, const char *var, const char *val);
 const char *flux_cmd_getopt (flux_cmd_t *cmd, const char *var);
-# 3490 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3488 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef struct flux_subprocess flux_subprocess_t;
-# 3502 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3500 "/__w/flux-python/flux-python/src/_core_clean.h"
 typedef enum {
     FLUX_SUBPROCESS_INIT,
     FLUX_SUBPROCESS_RUNNING,
@@ -2084,17 +2096,15 @@ typedef struct {
 
 
 
-typedef void (*subprocess_log_f) (void *arg,
-                                  const char *file,
-                                  int line,
-                                  const char *func,
-                                  const char *subsys,
-                                  int level,
-                                  const char *fmt,
-                                  va_list args);
-# 3586 "/__w/flux-python/flux-python/src/_core_clean.h"
-void flux_standard_output (flux_subprocess_t *p, const char *stream);
-# 3608 "/__w/flux-python/flux-python/src/_core_clean.h"
+typedef void (*subprocess_log_f)(void *arg,
+                                 const char *file,
+                                 int line,
+                                 const char *func,
+                                 const char *subsys,
+                                 int level,
+                                 const char *fmt,
+                                 va_list args);
+# 3594 "/__w/flux-python/flux-python/src/_core_clean.h"
 flux_subprocess_t *flux_local_exec (flux_reactor_t *r,
                                     int flags,
                                     const flux_cmd_t *cmd,
@@ -2109,8 +2119,8 @@ flux_subprocess_t *flux_local_exec_ex (flux_reactor_t *r,
                                        void *log_data);
 
 flux_subprocess_t *flux_rexec (flux_t *h,
-                 int rank,
-          int flags,
+                               int rank,
+                               int flags,
                                const flux_cmd_t *cmd,
                                const flux_subprocess_ops_t *ops);
 
@@ -2122,15 +2132,18 @@ flux_subprocess_t *flux_rexec_ex (flux_t *h,
                                   const flux_subprocess_ops_t *ops,
                                   subprocess_log_f log_fn,
                                   void *log_data);
-# 3645 "/__w/flux-python/flux-python/src/_core_clean.h"
-int flux_subprocess_stream_start (flux_subprocess_t *p, const char *stream);
-int flux_subprocess_stream_stop (flux_subprocess_t *p, const char *stream);
-int flux_subprocess_stream_status (flux_subprocess_t *p, const char *stream);
-# 3658 "/__w/flux-python/flux-python/src/_core_clean.h"
+
+
+
+
+
+void flux_subprocess_stream_start (flux_subprocess_t *p, const char *stream);
+void flux_subprocess_stream_stop (flux_subprocess_t *p, const char *stream);
+# 3638 "/__w/flux-python/flux-python/src/_core_clean.h"
 int flux_subprocess_write (flux_subprocess_t *p,
-             const char *stream,
+                           const char *stream,
                            const char *buf,
-      size_t len);
+                           size_t len);
 
 
 
@@ -2138,12 +2151,12 @@ int flux_subprocess_write (flux_subprocess_t *p,
 
 
 int flux_subprocess_close (flux_subprocess_t *p, const char *stream);
-# 3681 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3661 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_read (flux_subprocess_t *p,
                                   const char *stream,
                                   int len,
-      int *lenp);
-# 3697 "/__w/flux-python/flux-python/src/_core_clean.h"
+                                  int *lenp);
+# 3677 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_read_line (flux_subprocess_t *p,
                                        const char *stream,
                                        int *lenp);
@@ -2154,10 +2167,10 @@ const char *flux_subprocess_read_line (flux_subprocess_t *p,
 const char *flux_subprocess_read_trimmed_line (flux_subprocess_t *p,
                                                const char *stream,
                                                int *lenp);
-# 3717 "/__w/flux-python/flux-python/src/_core_clean.h"
-int flux_subprocess_read_stream_closed (flux_subprocess_t *p,
-                                        const char *stream);
-# 3736 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3696 "/__w/flux-python/flux-python/src/_core_clean.h"
+bool flux_subprocess_read_stream_closed (flux_subprocess_t *p,
+                                         const char *stream);
+# 3715 "/__w/flux-python/flux-python/src/_core_clean.h"
 const char *flux_subprocess_getline (flux_subprocess_t *p,
                                      const char *stream,
                                      int *lenp);
@@ -2175,9 +2188,14 @@ flux_future_t *flux_subprocess_kill (flux_subprocess_t *p, int signo);
 
 
 
-void flux_subprocess_ref (flux_subprocess_t *p);
-void flux_subprocess_unref (flux_subprocess_t *p);
-# 3763 "/__w/flux-python/flux-python/src/_core_clean.h"
+void flux_subprocess_destroy (flux_subprocess_t *p);
+
+
+
+
+
+
+
 flux_subprocess_state_t flux_subprocess_state (flux_subprocess_t *p);
 
 
@@ -2225,8 +2243,8 @@ flux_reactor_t * flux_subprocess_get_reactor (flux_subprocess_t *p);
 
 int flux_subprocess_aux_set (flux_subprocess_t *p,
                              const char *name,
-        void *ctx,
-        flux_free_f free);
+                             void *ctx,
+                             flux_free_f free);
 
 
 
@@ -2241,7 +2259,7 @@ void *flux_subprocess_aux_get (flux_subprocess_t *p, const char *name);
 
 void flux_subprocess_channel_incref (flux_subprocess_t *p, const char *name);
 void flux_subprocess_channel_decref (flux_subprocess_t *p, const char *name);
-# 3839 "/__w/flux-python/flux-python/src/_core_clean.h"
+# 3818 "/__w/flux-python/flux-python/src/_core_clean.h"
 extern "Python" void message_handler_wrapper(flux_t *, flux_msg_handler_t *, const flux_msg_t *, void *);
 
 
